

# Set a working directory -------------------------------------------------

setwd("N://Alfonso_Gomez//2 - Raw Image Files//181203_SLO_dV_assay//CellProfAnalys//9C12")

Masked_virus <- read.csv2("SLO_9C12_dV_wt_Maskedvirus.csv", header = T, sep = ",")
Back9C12 <- read.csv2("Back_9C12_dV_wt_Maskedvirus.csv", header = T, sep = ",")


# Extract the important information from your sample ----------------------

library("stringr")

add_my_numbers1 <- function(data){
  a <- str_split_fixed(data$Metadata_sample,"_",n = 5)
  Vir <- as.character(a[,3])
  SLO <- as.character(a[,4])
  Tim <- as.numeric(a[,5])
  data <- cbind(data, "Virus"=Vir, "SLO"=SLO, "Time"=Tim)
  return(data)
}

Con_time <- add_my_numbers1(Masked_virus)
Con_time_Back <- add_my_numbers1(Back9C12)

Con_time <- as.data.frame(Con_time)


# Transform your intensity values into numerical --------------


as.numeric.factor <- function(x){
  as.numeric(levels(x))[x]
}


Con_time$Intensity_MeanIntensity_Atto <- as.numeric.factor(Con_time$Intensity_MeanIntensity_Atto)
Con_time$Intensity_MeanIntensity_Hex <- as.numeric.factor(Con_time$Intensity_MeanIntensity_Hex)

Con_time_Back$Intensity_MeanIntensity_Atto <- as.numeric.factor(Con_time_Back$Intensity_MeanIntensity_Atto)
Con_time_Back$Intensity_MeanIntensity_Hex <- as.numeric.factor(Con_time_Back$Intensity_MeanIntensity_Hex)



# Plot your intensities to check your dataset -----------------------------


library('ggplot2')

Con_time_M <- subset(Con_time, Con_time$Virus != 'Mock')


Con_time_M$Virus <- factor(Con_time_M$Virus)
Con_time_M$Virus <- factor(Con_time_M$Virus, levels = c('wt', 'dV'))

ggplot(data = Con_time_M,aes(x = Metadata_sample, y = Intensity_MeanIntensity_Hex))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  facet_grid(.~Virus)+
  ylab("EdC intensity in VP") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))

ggplot(data = Con_time_gen,aes(x = Time, y = Intensity_MeanIntensity_Hex))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  facet_grid(.~Virus)+
  ylab("Hex intensity in Genomes") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))


# Convert your variables into a binary format -----------------------------
# so you can easily process them


Con_time$Time <- gsub("40","1", Con_time$Time)
Con_time$Time <- gsub("0","0", Con_time$Time)

Con_time$Virus <- gsub("Mock","0", Con_time$Virus)
Con_time$Virus <- gsub("dV","1", Con_time$Virus)
Con_time$Virus <- gsub("wt","2", Con_time$Virus)

Con_time$SLO <- gsub("Neg","0", Con_time$SLO)
Con_time$SLO <- gsub("Pos","1", Con_time$SLO)
Con_time$SLO <- gsub("Try","2", Con_time$SLO)

Con_time$Time <- as.numeric(Con_time$Time)
Con_time$Virus <- as.numeric(Con_time$Virus)
Con_time$SLO <- as.numeric(Con_time$SLO)


# Try to find a threshold for your variables ------------------------------

back <- subset(Con_time, Con_time$Metadata_sample =="181203_SLO_wt_Neg_40")

bSLO <- Con_time_Back[which(Con_time_Back$Intensity_MeanIntensity_Hex >= 0.07),]
bSLO2 <- back[which(back$Intensity_MeanIntensity_Hex >= 0.07),]

## Time for the experiment
## Count the amount of virus particles per cell as well as the amount of positive VP

output2 <- matrix(nrow = 0, ncol = 7)

Vir_counting <- function(exp){
  for (Vir in 1:2) {
    for (Ti in 0:1) {
      for (SL in 0:2){
        Tim <- subset(exp, (exp$SLO == SL) & (exp$Virus == Vir) & (exp$Time == Ti))
        for (sit in 0:8) {
          ce <- subset(Tim, (Tim$Metadata_Site == sit))
          ncel <- max(ce$Parent_Cell, na.rm = T)
          if (ncel == -Inf) {
            output2 <- output2
          } else {
            for (c in 1:ncel) {
              Viruses <- length(ce[ce[,"Parent_Cell"] == c,][,1])
              Hex_Pos <- length(ce[(ce[,"Parent_Cell"] == c & ce["Intensity_MeanIntensity_Hex"] >= 0.1),][,1])
              Percentpos <- (Hex_Pos/Viruses)*100
              if (is.nan(Percentpos)){
                Percentpos <- 0
              }
              output2 <- rbind(output2,c(Vir, Ti, SL, c, Viruses, Hex_Pos, Percentpos))
            }
          }
        }
      }
    }
  }
  return(output2)
}


EndEsc_cellcount <- Vir_counting(Con_time)

EndEsc_cellcount <- as.data.frame(EndEsc_cellcount)

colnames(EndEsc_cellcount) <- c("Virus", "Time","SLO", "Cell", "Virus_particles", 
                            "Hex_VP_pos","Percent_pos")


EndEsc_cellcount$Virus <- gsub("0","Mock", EndEsc_cellcount$Virus)
EndEsc_cellcount$Virus <- gsub("1","dV", EndEsc_cellcount$Virus)
EndEsc_cellcount$Virus <- gsub("2","wt", EndEsc_cellcount$Virus)

EndEsc_cellcount$Time <- gsub("0","0min", EndEsc_cellcount$Time)
EndEsc_cellcount$Time <- gsub("1","40min", EndEsc_cellcount$Time)

EndEsc_cellcount$SLO <- gsub("0","Notrt", EndEsc_cellcount$SLO)
EndEsc_cellcount$SLO <- gsub("1","SLO", EndEsc_cellcount$SLO)
EndEsc_cellcount$SLO <- gsub("2","Try", EndEsc_cellcount$SLO)


EndEsc_cellcount_dV <- subset(EndEsc_cellcount, (EndEsc_cellcount$Virus =="dV"))

EndEsc_cellcount_wt <- subset(EndEsc_cellcount, (EndEsc_cellcount$Virus == "wt"))


# Plot nicely your results ------------------------------------------------

ggplot(data = EndEsc_cellcount,aes(x = Time, y = Percent_pos, fill = SLO))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  facet_grid(.~Virus)+
  ylab("Percentage 9C12 pos VP per cell") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))


# Save your progress ------------------------------------------------------

write.csv2(EndEsc_cellcount_dV, file = "190112_SLO_dV_virus_count.csv")
write.csv2(EndEsc_cellcount_wt, file = "190112_SLO_wt_virus_count.csv")



