
setwd("N://Alfonso_Gomez//2 - Raw Image Files//181203_SLO_dV_assay//CellProfAnalys//Alexa488")

Masked_TS1 <- read.csv2("SLO_TS1_Maskedvirus.csv", header = T, sep = ",")
Back_TS1 <- read.csv2("Back_TS1_Maskedvirus.csv", header = T, sep = ",")

library("stringr")

add_my_numbers1 <- function(data){
  a <- str_split_fixed(data$Metadata_sample,"_",n = 5)
  Vir <- as.character(a[,3])
  SLO <- as.character(a[,4])
  Tim <- as.numeric(a[,5])
  data <- cbind(data, "Virus"=Vir, "SLO"=SLO, "Time"=Tim)
  return(data)
}

Con_time_TS1 <- add_my_numbers1(Masked_TS1)
Con_time_Back_TS1 <- add_my_numbers1(Back_TS1)

Con_time <- as.data.frame(Con_time)

######
## Now its time to count the viruses (Pos, Neg,...)
######
## First transform the columns of the signals into numbers (not characters)

as.numeric.factor <- function(x){
  as.numeric(levels(x))[x]
}


Con_time_TS1$Intensity_MeanIntensity_Alexa488 <- as.numeric.factor(Con_time_TS1$Intensity_MeanIntensity_Alexa488)
Con_time_TS1$Intensity_MeanIntensity_Ab <- as.numeric.factor(Con_time_TS1$Intensity_MeanIntensity_Ab)

Con_time_Back_TS1$Intensity_MeanIntensity_Alexa488 <- as.numeric.factor(Con_time_Back_TS1$Intensity_MeanIntensity_Alexa488)
Con_time_Back_TS1$Intensity_MeanIntensity_Ab <- as.numeric.factor(Con_time_Back_TS1$Intensity_MeanIntensity_Ab)


######
######  Plot the intensities
######

library('ggplot2')

Con_time_M <- subset(Con_time, Con_time$Virus != 'Mock')


Con_time_M$Virus <- factor(Con_time_M$Virus)
Con_time_M$Virus <- factor(Con_time_M$Virus, levels = c('wt', 'dV'))

ggplot(data = Con_time_TS1,aes(x = Metadata_sample, y = Intensity_MeanIntensity_Ab))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  facet_grid(.~Virus)+
  ylab("EdC intensity in VP") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))



##################
## Convert those treatments into numbers so the analysis will be easier
##################


Con_time_TS1$Time <- gsub("40","1", Con_time_TS1$Time)
Con_time_TS1$Time <- gsub("0","0", Con_time_TS1$Time)

Con_time_TS1$Virus <- gsub("Mock","0", Con_time_TS1$Virus)
Con_time_TS1$Virus <- gsub("TS","1", Con_time_TS1$Virus)

Con_time_TS1$SLO <- gsub("Neg","0", Con_time_TS1$SLO)
Con_time_TS1$SLO <- gsub("Pos","1", Con_time_TS1$SLO)

Con_time_TS1$Time <- as.numeric(Con_time_TS1$Time)
Con_time_TS1$Virus <- as.numeric(Con_time_TS1$Virus)
Con_time_TS1$SLO <- as.numeric(Con_time_TS1$SLO)

#######
####### Set the background
#######

backgroundTS <- subset(Con_time_TS1, Con_time_TS1$Metadata_sample =="181203_SLO_TS_Neg_40")

bSLOTS <- Con_time_Back_TS1[which(Con_time_Back_TS1$Intensity_MeanIntensity_Ab >= 0.01),]
bSLOTS2 <- backgroundTS[which(backgroundTS$Intensity_MeanIntensity_Ab >= 0.01),]

## Time for the experiment
#Count the amount of virus particles per cell as well as the amount of positive pVI VP

output2 <- matrix(nrow = 0, ncol = 7)

Vir_counting <- function(exp){
  for (Vir in 1:2) {
    for (Ti in 0:1) {
      for (SL in 0:2){
        Tim <- subset(exp, (exp$SLO == SL) & (exp$Virus == Vir) & (exp$Time == Ti))
        for (sit in 0:8) {
          ce <- subset(Tim, (Tim$Metadata_Site == sit))
          ncel <- max(ce$Parent_Cell, na.rm = T)
          if (ncel == -Inf) {
            output2 <- output2
          } else {
            for (c in 1:ncel) {
              Viruses <- length(ce[ce[,"Parent_Cell"] == c,][,1])
              Ab_Pos <- length(ce[(ce[,"Parent_Cell"] == c & ce["Intensity_MeanIntensity_Ab"] >= 0.02),][,1])
              Percentpos <- (Ab_Pos/Viruses)*100
              if (is.nan(Percentpos)){
                Percentpos <- 0
              }
              output2 <- rbind(output2,c(Vir, Ti, SL, c, Viruses, Ab_Pos, Percentpos))
            }
          }
        }
      }
    }
  }
  return(output2)
}


EndEsc_cellcount_TS <- Vir_counting(Con_time_TS1)

EndEsc_cellcount_TS <- as.data.frame(EndEsc_cellcount_TS)

colnames(EndEsc_cellcount_TS) <- c("Virus", "Time","SLO", "Cell", "Virus_particles", 
                                "Ab_VP_pos","Percent_pos")


EndEsc_cellcount_TS$Virus <- gsub("0","Mock", EndEsc_cellcount_TS$Virus)
EndEsc_cellcount_TS$Virus <- gsub("1","TS", EndEsc_cellcount_TS$Virus)

EndEsc_cellcount_TS$Time <- gsub("0","0min", EndEsc_cellcount_TS$Time)
EndEsc_cellcount_TS$Time <- gsub("1","40min", EndEsc_cellcount_TS$Time)

EndEsc_cellcount_TS$SLO <- gsub("0","Notrt", EndEsc_cellcount_TS$SLO)
EndEsc_cellcount_TS$SLO <- gsub("1","SLO", EndEsc_cellcount_TS$SLO)


ggplot(data = EndEsc_cellcount_TS,aes(x = Time, y = Percent_pos, fill = SLO))+
  geom_dotplot(binaxis='y', stackdir='center',
               stackratio=0.01, dotsize=0.3, alpha=0.5, position = position_jitter(width = 0.2)) +
  geom_boxplot(color = "black", outlier.colour = NA) +
  stat_summary(fun.data=mean_sdl, fun.args = list(mult=1), 
               geom="pointrange", color="red") +
  facet_grid(.~Virus)+
  ylab("Percentage 9C12 pos VP per cell") +
  theme_classic() +
  theme(axis.text.x = element_text(angle = 45, size=9, hjust = 1, colour = 'black'), axis.ticks = element_line(colour = 'black'))+
  theme(axis.text.y = element_text(colour = 'black'))

write.csv2(EndEsc_cellcount_TS, file = "190112_SLO_TS_virus_count.csv")

